@@ -26,6 +26,9 @@ BDB - Asynchronous Berkeley DB access
  };
  db_sync $db;
 
+ # when you also use Coro, management is easy:
+ use Coro::BDB;
+
  # automatic result processing with AnyEvent:
  our $FH; open $FH, "<&=" . BDB::poll_fileno;
  our $WATCHER = AnyEvent->io (fh => $FH, poll => 'r', cb => \&BDB::poll_cb);
@@ -109,7 +112,7 @@ use strict 'vars';
 use base 'Exporter';
 
 BEGIN {
-   our $VERSION = '1.4';
+   our $VERSION = '1.41';
 
    our @BDB_REQ = qw(
       db_env_open db_env_close db_env_txn_checkpoint db_env_lock_detect
@@ -390,6 +393,8 @@ Methods available on DBC/$dbc handles:
            if (dbc)
              dbc->c_close (dbc);
 
+   $int = $cursor->set_priority ($priority = PRIORITY_*)
+
 =head4 Example:
 
    my $c = $db->cursor;
